@@ -26,11 +26,20 @@
 /* Each algo is defined as a bit toggled in a 32 bits integer,
  * so we can easily ask for all availables ones
  */
-#define BCTBX_DHM_UNSET		0x00000000
-#define BCTBX_DHM_2048		0x00000001
-#define BCTBX_DHM_3072		0x00000002
-#define BCTBX_ECDH_X25519	0x00000004
-#define BCTBX_ECDH_X448		0x00000008
+#define BCTBX_DHM_UNSET				0x00000000
+#define BCTBX_DHM_2048				0x00000001
+#define BCTBX_DHM_3072				0x00000002
+#define BCTBX_ECDH_X25519			0x00000004
+#define BCTBX_ECDH_X448				0x00000008
+#define BCTBX_KEM_KYBER512			0x00000010
+#define BCTBX_KEM_KYBER768			0x00000020
+#define BCTBX_KEM_KYBER1024			0x00000040
+#define BCTBX_KEM_HQC128			0x00000080
+#define BCTBX_KEM_HQC192			0x00000100
+#define BCTBX_KEM_HQC256			0x00000200
+#define BCTBX_KEM_X25519			0x00000400
+#define BCTBX_KEM_X448				0x00000800
+
 
 /* EdDSA defines */
 #define BCTBX_EDDSA_UNSET	0
@@ -92,16 +101,17 @@ bctoolbox will fail to compile if these values are not in sync with the decaf on
 #define BCTBX_ERROR_UNSUPPORTED_HASH_FUNCTION	-0x70020008
 
 /* SSL related */
+#define BCTBX_ERROR_NET_CONN_RESET		-0x70030000
 #define BCTBX_ERROR_INVALID_SSL_CONFIG		-0x70030001
 #define BCTBX_ERROR_INVALID_SSL_TRANSPORT	-0x70030002
 #define BCTBX_ERROR_INVALID_SSL_ENDPOINT	-0x70030004
 #define BCTBX_ERROR_INVALID_SSL_AUTHMODE	-0x70030008
 #define BCTBX_ERROR_INVALID_SSL_CONTEXT		-0x70030010
 
-#define BCTBX_ERROR_NET_WANT_READ			-0x70032000
-#define BCTBX_ERROR_NET_WANT_WRITE			-0x70034000
+#define BCTBX_ERROR_NO_CLIENT_CERTIFICATE	-0x70031000
+#define BCTBX_ERROR_NET_WANT_READ		-0x70032000
+#define BCTBX_ERROR_NET_WANT_WRITE		-0x70034000
 #define BCTBX_ERROR_SSL_PEER_CLOSE_NOTIFY	-0x70038000
-#define BCTBX_ERROR_NET_CONN_RESET			-0x70030000
 
 /* Symmetric ciphers related */
 #define BCTBX_ERROR_AUTHENTICATION_FAILED	-0x70040000
@@ -878,7 +888,7 @@ BCTBX_PUBLIC void bctbx_sha256(const uint8_t *input,
 		uint8_t hashLength,
 		uint8_t *output);
 
-/*
+/**
  * @brief HMAC-SHA512 wrapper
  * @param[in] 	key		HMAC secret key
  * @param[in] 	keyLength	HMAC key length
