@@ -515,15 +515,59 @@ BCTBX_PUBLIC char *bctbx_dirname(const char *path);
 BCTBX_PUBLIC char *bctbx_basename(const char *path);
 
 /**
- * Tests if a file with given pathname exists. Return 0 if yes, -1 otherwise.
+ * Tests if a file with given path exists.
+ *
+ * @param[in]	path	the file path to test
+ * @return 0 if yes, -1 otherwise.
 **/
 BCTBX_PUBLIC int bctbx_file_exist(const char *pathname);
 
 /**
- * Tests if a directory with given pathname exists. Return 0 if yes, -1 otherwise.
+ * Tests if a directory with given pathname exists.
+ *
+ * @param[in]	pathname	the directory path to test
+ * @return TRUE if yes, FALSE otherwise.
 **/
 BCTBX_PUBLIC bool_t bctbx_directory_exists(const char *pathname);
 
+/* we just need to be able to return a pointer of type bctbx_list_t, the actual structure is defined in list.h */
+struct _bctbx_list;
+
+/**
+ * Parse a directory and return a list of all its files and subdirectories
+ *
+ * @param[in]	path		The directory to parse
+ * @param[in]	file_type	select only files with that extension, can be NULL in that case it returns all files.
+ *
+ * @note	. and .. file descriptors are never returned in the list, even when file_type is set to NULL
+ * 		The returned list includes the given path in each item
+ *
+ * @return	the list of all files in the given directory matching the given file type.
+ * 		The list must be destroyed using bctbx_list_free_with_data(<returned list>, bctbx_free)
+ **/
+BCTBX_PUBLIC struct _bctbx_list *bctbx_parse_directory(const char *path, const char *file_type);
+
+/**
+ * Create a directory
+ * Note: parent directory must exists, this function cannot create a complete path
+ *
+ * @param[in]	path	the directory to create
+ *
+ * @return 0 on success
+ **/
+BCTBX_PUBLIC int bctbx_mkdir(const char *path);
+
+/**
+ * Delete a directory
+ *
+ * @param[in]	path		the directory to delete
+ * @param[in]	recursive	if false, the directory must be empty to be deleted otherwise recursively delete with all content
+ *
+ * @return 0 on success
+ **/
+BCTBX_PUBLIC int bctbx_rmdir(const char *path, bool_t recursive);
+
+
 /**
  * @brief return a timeSpec structure(sec and nsec) containing current time(WARNING: there is no guarantees it is UTC ).
  *        The time returned may refers to UTC or last boot.
@@ -605,7 +649,7 @@ BCTBX_PUBLIC int bctbx_sockaddr_to_printable_ip_address(struct sockaddr *sa, soc
  -V4.
 **/
 BCTBX_PUBLIC struct addrinfo *bctbx_addrinfo_sort(struct addrinfo *ai);
-	
+
 
 /**
  * Convert a numeric ip address and port into an addrinfo, whose family will be as specified in the first argument.
@@ -675,6 +719,7 @@ typedef int bctbx_pipe_t;
 #define BCTBX_PIPE_INVALID (-1)
 #endif
 
+BCTBX_PUBLIC bctbx_pipe_t bctbx_server_pipe_create_by_path(const char *path);
 BCTBX_PUBLIC bctbx_pipe_t bctbx_server_pipe_create(const char *name);
 /*
  * warning: on win32 bctbx_server_pipe_accept_client() might return INVALID_HANDLE_VALUE without
@@ -770,6 +815,40 @@ BCTBX_PUBLIC void bctbx_uint64_to_str(uint8_t output_string[17], uint64_t input_
  */
 BCTBX_PUBLIC uint64_t bctbx_str_to_uint64(const uint8_t input_string[17]);
 
+/**
+ * @brief Call of strcasecmp where parameters can be NULL.
+ *
+ * @param[in] a first string to compare. @maybenil
+ * @param[in] b second string to compare. @maybenil
+ *
+ *@return the value of strcasecmp.
+ */
+BCTBX_PUBLIC int bctbx_strcasecmp(const char *a, const char *b);
+
+/**
+ * @brief Call of strcmp where parameters can be NULL.
+ *
+ * @param[in] a first string to compare. @maybenil
+ * @param[in] b second string to compare. @maybenil
+ *
+ *@return the value of strcmp.
+ */
+BCTBX_PUBLIC int bctbx_strcmp(const char *a, const char *b);
+
+/**
+ * @brief Set the name of the calling thread.
+ * This can ease the analysis of bug reports, such as ANR reports on Android.
+ * @param[in] the name. Its length is subject to underlying platform's limitations.
+ */
+BCTBX_PUBLIC void bctbx_set_self_thread_name(const char *name);
+
+/**
+ * @brief Set handlers to catch exceptions and write the stack trace into log. Available for Windows.
+ * It keeps old handlers.
+ * @param[in] if TRUE, prepends handlers with bctoolbox hooks. If FALSE, remove them and replace by old hooks (stored from the last call of bctbx_set_stack_trace_hooks() ). By default, it is FALSE.
+ */
+BCTBX_PUBLIC void bctbx_set_stack_trace_hooks(bool_t use_bctbx_hooks);
+
 #ifdef __cplusplus
 }
 
